#!/bin/env dls-python
import PandATest
import Lvds
import Ttl
import EncoderUnplugged as Encoder

"""
LVDS and TTL Unplugged tests
"""


class Unplugged(PandATest.PandATest):

    def __init__(self, *args, **kwargs):
        super(Unplugged, self).__init__(*args, **kwargs)
        # LVDS UNPLUGGED
        self.lu = Lvds.Lvds(*args, **kwargs)
        self.lu .inputs = [1, 2]
        self.lu .outputs = [1, 2]
        self.lu .ch_connect = {
            self.lu .outputs[0]: -1,
            self.lu .outputs[1]: -1
        }
        self.default_val = 1
        self.lu.unplugged = True

        #TTL UNPLUGGED
        self.tu = Ttl.Ttl(*args, **kwargs)
        self.tu.outputs = [1,2,3,4,5,6,7,8,9,10]
        self.tu.inputs = [1,2,3,4,5,6]
        self.tu.ch_connect = {
            self.tu.outputs[0]: -1,
            self.tu.outputs[1]: -1,
            self.tu.outputs[2]: -1,
            self.tu.outputs[3]: -1,
            self.tu.outputs[4]: -1,
            self.tu.outputs[5]: -1,
            self.tu.outputs[6]: -1,
            self.tu.outputs[7]: -1,
            self.tu.outputs[8]: -1,
            self.tu.outputs[9]: -1,
        }
        self.tu.default_val = 0
        self.tu.unplugged = True

        #ENCODER UNPLUGGED
        self.enc1 = Encoder.Encoder(*args, **kwargs)
        self.enc1.blocknum = 1
        self.enc1.unplugged = True
        self.enc2 = Encoder.Encoder(*args, **kwargs)
        self.enc2.blocknum = 2
        self.enc2.unplugged = True
        self.enc3 = Encoder.Encoder(*args, **kwargs)
        self.enc3.blocknum = 3
        self.enc3.unplugged = True
        self.enc4 = Encoder.Encoder(*args, **kwargs)
        self.enc4.blocknum = 4
        self.enc4.unplugged = True

    def test_code(self):
        self.run_unplugged_test(self.lu)
        self.run_unplugged_test(self.tu)
        self.run_unplugged_test(self.enc1)
        self.run_unplugged_test(self.enc2)
        self.run_unplugged_test(self.enc3)
        self.run_unplugged_test(self.enc4)


    def run_unplugged_test(self, test_cls):
        self.logger.info('---- {} {} {} {}'.format(test_cls.__class__.__name__,
                                                   test_cls.blocknum,
                                                   'UNPLUGGED',
                                                   ''.join(['-']*28)
                                                   ))
        for attempt in [1, 2]:
            self.logger.info('---- ATTEMPT {} {}'.format(attempt, ''.join(['-']*28)))
            test_cls.test_code()
            if test_cls.test_result.count(0) != 0 and attempt == 1:
                test_cls.test_result = []
                self.check_connectors(test_cls.__class__.__name__, test_cls.blocknum)
            elif test_cls.test_result.count(0) == 0:
                print 'TEST PASSED! ({} {})'.format(test_cls.__class__.__name__,
                                                    test_cls.blocknum)
                break

    def get_summary(self):
        tests = [self.lu, self.tu, self.enc1, self.enc2, self.enc3, self.enc4]
        summary = []
        for test in tests:
            summary.append("{:<12}{:<12}{:<10} ERRORS: {}".format(
                                                    test.__class__.__name__,
                                                    test.unplugged_string[test.unplugged],
                                                    test.blocknum,
                                                    test.test_result.count(0)))
        return summary

    def get_user_input(self):
        inputy = '.'
        while inputy not in ['']:
            print "Loopback connectors NOT connected, OK ? [return]"
            inputy = raw_input()

    def check_connectors(self, test, block_no):
        inputy = '.'
        while inputy not in ['']:
            print "TEST FAILED! ({} {}), Check connectors connected [return]".format(test, block_no)
            inputy = raw_input()
